@@ -26,7 +26,7 @@ use vars
 
 $File::Copy::Recursive::KeepMode = 0;
 
-$VERSION = version->declare('v4.2.6');
+$VERSION = version->declare('v4.3.2');
 @ISA     = qw(Exporter);
 
 @EXPORT
@@ -578,7 +578,7 @@ sub _load_config {
         unless ( defined $PARAMS{$key} ) {
             logger(
                 maketext(
-                    "WARNING: Unknow config key [_1], ignoring.\n", $key
+                    "WARNING: Unknown config key [_1], ignoring.\n", $key
                 ),
                 RED
             );
@@ -865,6 +865,7 @@ sub new {
         $NOCOLOURS = delete( $args->{NOCOLOURS} );
         my $brand_dir = delete( $args->{brand_dir} );
         my $allow_network =  delete( $args->{allow_network} );
+        my $no_clean =  delete( $args->{no_clean} );
 
         if ( %{$args} ) {
             croak(
@@ -879,6 +880,7 @@ sub new {
         $SINGLETON = $self;
 
         $self->{allow_network} = $allow_network;
+        $self->{no_clean} = $no_clean;
 
         # BUGBUG this should be replaced by Publican::Config
         if ( $^O eq 'MSWin32' ) {
