@@ -131,6 +131,7 @@ sub update_pot {
         $pot_file =~ s/\.xml/\.pot/;
         $pot_file =~ s/^$source_dir/pot/;
         $pot_file =~ m|^(.*)/([^/]+)$|;
+
         my $path     = $1;
         my $filename = $2;
         mkpath($path) if ( !-d $path );
@@ -575,6 +576,7 @@ Get the strings to translate from an XML::TreeBuilder object
 sub get_msgs {
     my ( $self, $args ) = @_;
     my $doc = delete( $args->{doc} ) || croak("doc is a mandatory argument");
+
     my $filename = delete( $args->{filename} )
         || croak("filename is a mandatory argument");
 
@@ -1057,15 +1059,15 @@ sub detag {
         chomp($string);
 
         # remove start tag & leading space
-        $string =~ s/^<$name[^>]*>\s*//;
+        $string =~ s/^<$name[^>]*>[ \t]*//;
 
         # remove close tag & trailing
-        $string =~ s/\s*<\/$name>\s*$//;
+        $string =~ s/[ \t]*<\/$name>\s*$//;
 
-        $string =~ s/\n/ /g;     # CR
-        $string =~ s/^\s*//g;    # space at start of line
-        $string =~ s/\s*$//g;    # space at end of line
-        $string =~ s/\s+/ /g;    # collapse spacing
+        $string =~ s/\n/ /g;        # CR
+        $string =~ s/^[ \t]*//g;    # space at start of line
+        $string =~ s/[ \t]*$//g;    # space at end of line
+        $string =~ s/[ \t]+/ /g;    # collapse spacing
     }
 
     $string =~ s/&#38;/&amp;/g;
