@@ -5,23 +5,16 @@ use warnings;
 use Carp;
 use XML::TreeBuilder;
 use Publican;
-use vars qw($VERSION);
 use File::pushd;
 use Term::ANSIColor qw(:constants);
 use File::Basename;
-
-$VERSION = 0.1;
+use Cwd qw(realpath);
+use File::Spec qw(abs2rel);
 
 =head1 NAME
 
 Publican::TreeView - Dumper for XInclude project structure.
 
-
-=head1 VERSION
-
-This document describes Publican::TreeView version 0.1
-
-
 =head1 SYNOPSIS
 
     use Publican;
@@ -168,7 +161,11 @@ sub print_unused {
                 $self->print_unused(
                     { 'in_file' => "$path$filename", path => $path, } );
             }
-            $self->{used_files}->{qq|'$path$filename'|} = 1;
+
+            $filename = Cwd::realpath("$path$filename");
+            $filename = File::Spec->abs2rel($filename);
+
+            $self->{used_files}->{qq|'$filename'|} = 1;
         }
     }
 
