@@ -20,6 +20,7 @@ use XML::Simple;
 use Archive::Zip qw( :ERROR_CODES :CONSTANTS );
 use Publican::ConfigData;
 use HTML::TreeBuilder;
+use File::pushd;
 
 my $DB_NAME           = 'books';
 my $DEFAULT_LANG      = 'en-US';
@@ -166,6 +167,10 @@ my %PARAMS = (
             'This field is deprecated and will be removed from Publican in the future.'
         )
     },
+    home_link => {
+        descr => maketext(
+            "HTML anchor to inject in to the start of site navigation menu."),
+    },
 );
 
 # This is required to ensure that the correct localised strings are found when running
@@ -222,7 +227,9 @@ my %tmpl_strings = (
     'html-single_label'   => $locale->maketext('Single-page HTML'),
     pdf_label             => $locale->maketext('PDF'),
     epub_label            => $locale->maketext('EPUB'),
-    All                   => $locale->maketext('All'),
+    RssProdTitle =>
+        $locale->maketext('Subcribe to the RSS feed for this product'),
+    All => $locale->maketext('All'),
 );
 
 sub new {
@@ -270,6 +277,7 @@ sub new {
     my $debug             = $config->param('debug')             || 0;
     my $footer            = $config->param('footer')            || "";
     my $web_style         = $config->param('web_style')         || 1;
+    my $home_link         = $config->param('home_link')         || undef;
 
     my $self = bless { db_file => $db_file }, $class;
 
@@ -293,6 +301,7 @@ sub new {
     $self->{manual_toc_update} = $manual_toc_update;
     $self->{debug}             = $debug;
     $self->{web_style}         = $web_style;
+    $self->{home_link}         = $home_link;
 
     my $conf = { INCLUDE_PATH => $tmpl_path, ENCODING => 'utf8', };
 
@@ -483,7 +492,7 @@ sub add_entry {
         croak "unknown args: " . join( ", ", keys %{$arg} );
     }
 
-    $formats = lc $formats;
+    #    $formats = lc $formats;
     $abstract =~ s/\n/ /gm;
 
     my $sql = <<INSERT_ENTRY;
@@ -528,7 +537,7 @@ sub update_entry {
         croak "unknown args: " . join( ", ", keys %{$arg} );
     }
 
-    $formats = lc $formats;
+    #    $formats = lc $formats;
     $abstract =~ s/\n/ /gm;
 
     my $sql = <<INSERT_ENTRY;
@@ -858,9 +867,11 @@ sub regen_all_toc {
 
     $self->splash_pages() if ( $self->{web_style} == 2 );
 
-    unlink( $self->{toc_path} . '/toc.js' );
-    symlink( $self->{toc_path} . '/' . $self->{toc_js},
-        $self->{toc_path} . '/toc.js' );
+    my $dir = pushd( $self->{toc_path} );
+    unlink('toc.js');
+    symlink( $self->{toc_js}, 'toc.js' );
+    $dir = undef;
+
     return;
 }
 
@@ -1655,8 +1666,10 @@ SQL
 
             # write out book_lang_menu.tmpl
             my $book_lang_vars;
-            $book_lang_vars->{host}    = $host;
-            $book_lang_vars->{product} = $record->{product};
+            $book_lang_vars->{host}     = $host;
+            $book_lang_vars->{toc_path} = $self->{toc_path};
+            $book_lang_vars->{toc_path} = $self->{toc_path};
+            $book_lang_vars->{product}  = $record->{product};
             $book_lang_vars->{product_label}
                 = ( $record->{product_label} || $record->{product} );
             $book_lang_vars->{version} = $record->{version};
@@ -1739,6 +1752,10 @@ SQL
                 },
                 keys(%formats)
             );
+
+            $book_list{$product}{$version}{ $record->{name} }{formats}
+                = $book_ver_list{$product}{ $record->{name} }{$version}
+                {formats};
         }
 
         # write our books_index.tmpl
@@ -1867,6 +1884,7 @@ sub write_version_index {
     $index_vars->{product}          = $product;
     $index_vars->{version}          = $version;
     $index_vars->{host}             = $host;
+    $index_vars->{toc_path}         = $self->{toc_path};
     $index_vars->{book_list}        = $book_list;
     $index_vars->{lang}             = $lang;
     $index_vars->{langs}            = $langs;
@@ -1879,6 +1897,7 @@ sub write_version_index {
     $index_vars->{book_ver_list}    = $book_ver_list;
     $index_vars->{splash}           = $self->get_splash(
         { path => $self->{toc_path} . "/$lang/$product/$version" } );
+    $index_vars->{home_link} = $self->{home_link};
 
     $self->{Template}->process(
         'versions_index.tmpl', $index_vars,
@@ -1925,7 +1944,9 @@ sub write_product_index {
     my $index_vars;
     $index_vars->{style}         = $self->{web_style};
     $index_vars->{product}       = $product;
+    $index_vars->{toc_path}      = $self->{toc_path};
     $index_vars->{host}          = $host;
+    $index_vars->{toc_path}      = $self->{toc_path};
     $index_vars->{book_list}     = $book_list;
     $index_vars->{lang}          = $lang;
     $index_vars->{v_sort}        = \&v_sort;
@@ -1942,6 +1963,7 @@ sub write_product_index {
         { path => $self->{toc_path} . "/$lang/$product" } );
     $index_vars->{categories}
         = ( -d "$DEFAULT_TMPL_PATH/groups/$lang/$product" );
+    $index_vars->{home_link} = $self->{home_link};
 
     $self->{Template}->process(
         'products_index.tmpl', $index_vars,
@@ -1986,6 +2008,7 @@ sub write_product_menu {
     my $index_vars;
     $index_vars->{style}         = $self->{web_style};
     $index_vars->{host}          = $host;
+    $index_vars->{toc_path}      = $self->{toc_path};
     $index_vars->{book_list}     = $book_list;
     $index_vars->{lang}          = $lang;
     $index_vars->{products}      = \@products;
@@ -1995,6 +2018,7 @@ sub write_product_menu {
     $index_vars->{trans_strings} = $trans_strings;
     $index_vars->{footer}        = $self->{footer};
     $index_vars->{site_title}    = $self->{title};
+    $index_vars->{home_link}     = $self->{home_link};
 
 ## BUGBUG handle product labels
     $self->{Template}->process(
@@ -2049,6 +2073,7 @@ sub write_language_index {
     my $index_vars;
     $index_vars->{style}         = $self->{web_style};
     $index_vars->{host}          = $host;
+    $index_vars->{toc_path}      = $self->{toc_path};
     $index_vars->{book_list}     = $book_list;
     $index_vars->{lang}          = $lang;
     $index_vars->{products}      = \@products;
@@ -2063,6 +2088,7 @@ sub write_language_index {
     $index_vars->{site_title}    = $self->{title};
     $index_vars->{splash}
         = $self->get_splash( { path => $self->{toc_path} . "/$lang" } );
+    $index_vars->{home_link} = $self->{home_link};
 
     $self->{Template}->process(
         'language_index.tmpl', $index_vars,
@@ -2091,12 +2117,14 @@ sub write_language_labels {
     my $host = $self->{host};
 
     my $index_vars;
+    $index_vars->{toc_path}      = $self->{toc_path};
     $index_vars->{style}         = $self->{web_style};
     $index_vars->{lang}          = $lang;
     $index_vars->{labels}        = $labels;
     $index_vars->{trans_strings} = $trans_strings;
     $index_vars->{book_list}     = $book_list;
     $index_vars->{site_title}    = $self->{title};
+    $index_vars->{home_link}     = $self->{home_link};
 
 ## BUGBUG handle product labels
     $self->{Template}->process(
@@ -2140,8 +2168,9 @@ sub write_books_index {
             foreach my $version (@versions) {
 
                 my $index_vars;
-                $index_vars->{style} = $self->{web_style};
-                $index_vars->{host}  = $host;
+                $index_vars->{style}    = $self->{web_style};
+                $index_vars->{host}     = $host;
+                $index_vars->{toc_path} = $self->{toc_path};
                 $index_vars->{book} = $book_list->{$product}{$version}{$book};
                 $index_vars->{lang} = $lang;
                 $index_vars->{langs}    = $langs;
@@ -2155,6 +2184,7 @@ sub write_books_index {
                 $index_vars->{trans_strings} = $trans_strings;
                 $index_vars->{footer}        = $self->{footer};
                 $index_vars->{site_title}    = $self->{title};
+                $index_vars->{home_link}     = $self->{home_link};
 
                 $self->{Template}->process(
                     'books_index.tmpl',
